==> cryptlex_python_sdk-1.0.1.tar.gz: cryptlex_python_sdk-1.0.1/src/cryptlex_web_api_client/models/user_update_request_model.py <==
from typing import Any, Dict, List, Type, TypeVar, Union, cast

import attr

from ..models.user_metadata_request_model import UserMetadataRequestModel
from ..types import UNSET, Unset

T = TypeVar("T", bound="UserUpdateRequestModel")


@attr.s(auto_attribs=True)
class UserUpdateRequestModel:
    """ """

    first_name: str
    last_name: str
    email: str
    company: Union[Unset, None, str] = UNSET
    allow_customer_portal_access: Union[Unset, None, bool] = UNSET
    metadata: Union[Unset, None, List[UserMetadataRequestModel]] = UNSET
    tags: Union[Unset, None, List[str]] = UNSET
    role: Union[Unset, None, str] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        first_name = self.first_name
        last_name = self.last_name
        email = self.email
        company = self.company
        allow_customer_portal_access = self.allow_customer_portal_access
        metadata: Union[Unset, None, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.metadata, Unset):
            if self.metadata is None:
                metadata = None
            else:
                metadata = []
                for metadata_item_data in self.metadata:
                    metadata_item = metadata_item_data.to_dict()

                    metadata.append(metadata_item)

        tags: Union[Unset, None, List[str]] = UNSET
        if not isinstance(self.tags, Unset):
            if self.tags is None:
                tags = None
            else:
                tags = self.tags

        role = self.role

        field_dict: Dict[str, Any] = {}
        field_dict.update(
            {
                "firstName": first_name,
                "lastName": last_name,
                "email": email,
            }
        )
        if company is not UNSET:
            field_dict["company"] = company
        if allow_customer_portal_access is not UNSET:
            field_dict["allowCustomerPortalAccess"] = allow_customer_portal_access
        if metadata is not UNSET:
            field_dict["metadata"] = metadata
        if tags is not UNSET:
            field_dict["tags"] = tags
        if role is not UNSET:
            field_dict["role"] = role

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        first_name = d.pop("firstName")

        last_name = d.pop("lastName")

        email = d.pop("email")

        company = d.pop("company", UNSET)

        allow_customer_portal_access = d.pop("allowCustomerPortalAccess", UNSET)

        metadata = []
        _metadata = d.pop("metadata", UNSET)
        for metadata_item_data in _metadata or []:
            metadata_item = UserMetadataRequestModel.from_dict(metadata_item_data)

            metadata.append(metadata_item)

        tags = cast(List[str], d.pop("tags", UNSET))

        role = d.pop("role", UNSET)

        user_update_request_model = cls(
            first_name=first_name,
            last_name=last_name,
            email=email,
            company=company,
            allow_customer_portal_access=allow_customer_portal_access,
            metadata=metadata,
            tags=tags,
            role=role,
        )

        return user_update_request_model

==> cryptlex_python_sdk-1.0.3.tar.gz: cryptlex_python_sdk-1.0.3/src/cryptlex_web_api_client/models/user_update_request_model.py <==
from typing import Any, Dict, List, Type, TypeVar, Union, cast

import attr

from ..models.user_metadata_request_model import UserMetadataRequestModel
from ..types import UNSET, Unset

T = TypeVar("T", bound="UserUpdateRequestModel")


@attr.s(auto_attribs=True)
class UserUpdateRequestModel:
    """
    Attributes:
        first_name (str): First name of the user.
        last_name (str): Last name of the user.
        email (str): Email address of the user.
        company (Union[Unset, None, str]): Company of the user.
        allow_customer_portal_access (Union[Unset, None, bool]): Allow customer portal access.
        metadata (Union[Unset, None, List[UserMetadataRequestModel]]): List of metdata key/value pairs.
        tags (Union[Unset, None, List[str]]): List of tags.
        role (Union[Unset, None, str]): Role of the user.
    """

    first_name: str
    last_name: str
    email: str
    company: Union[Unset, None, str] = UNSET
    allow_customer_portal_access: Union[Unset, None, bool] = UNSET
    metadata: Union[Unset, None, List[UserMetadataRequestModel]] = UNSET
    tags: Union[Unset, None, List[str]] = UNSET
    role: Union[Unset, None, str] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        first_name = self.first_name
        last_name = self.last_name
        email = self.email
        company = self.company
        allow_customer_portal_access = self.allow_customer_portal_access
        metadata: Union[Unset, None, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.metadata, Unset):
            if self.metadata is None:
                metadata = None
            else:
                metadata = []
                for metadata_item_data in self.metadata:
                    metadata_item = metadata_item_data.to_dict()

                    metadata.append(metadata_item)

        tags: Union[Unset, None, List[str]] = UNSET
        if not isinstance(self.tags, Unset):
            if self.tags is None:
                tags = None
            else:
                tags = self.tags

        role = self.role

        field_dict: Dict[str, Any] = {}
        field_dict.update(
            {
                "firstName": first_name,
                "lastName": last_name,
                "email": email,
            }
        )
        if company is not UNSET:
            field_dict["company"] = company
        if allow_customer_portal_access is not UNSET:
            field_dict["allowCustomerPortalAccess"] = allow_customer_portal_access
        if metadata is not UNSET:
            field_dict["metadata"] = metadata
        if tags is not UNSET:
            field_dict["tags"] = tags
        if role is not UNSET:
            field_dict["role"] = role

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        first_name = d.pop("firstName")

        last_name = d.pop("lastName")

        email = d.pop("email")

        company = d.pop("company", UNSET)

        allow_customer_portal_access = d.pop("allowCustomerPortalAccess", UNSET)

        metadata = []
        _metadata = d.pop("metadata", UNSET)
        for metadata_item_data in _metadata or []:
            metadata_item = UserMetadataRequestModel.from_dict(metadata_item_data)

            metadata.append(metadata_item)

        tags = cast(List[str], d.pop("tags", UNSET))

        role = d.pop("role", UNSET)

        user_update_request_model = cls(
            first_name=first_name,
            last_name=last_name,
            email=email,
            company=company,
            allow_customer_portal_access=allow_customer_portal_access,
            metadata=metadata,
            tags=tags,
            role=role,
        )

        return user_update_request_model
